import chimera, Rotamers
from chimera import runCommand, selection
from Rotamers import getRotamers, useRotamer, NoResidueRotamersError

# -----------------------------------------------------------------------------
def userSelectsResidue(focus = False):
    print "Select an atom or a standard residue in the display."
    raw_input("Then bring the cursor back to this line and hit Enter.")
    atm_L = selection.currentAtoms()
    if len(atm_L) == 0: return None
    res = atm_L[0].residue
    if focus:
        runCommand("sel :" + str(res.id.position) + "." +
                   res.id.chainId + " za<8.0; focus sel; ~sel")
    return res

#==============================================================================
# Mainline:
#==============================================================================

targetPath = raw_input("Type 4 character PDB ID: \n")
prot = chimera.openModels.open(targetPath, type="PDB")[0]

runCommand("set bg_color white; ~ribbon; repr stick; show")

selR = userSelectsResidue(focus = True)
if not selR: selR = prot.residues[0] # Use first residue if user does not select.
resStr = ":" + str(selR.id.position) + "." + selR.id.chainId

runCommand("repr bs " + resStr)

print "Use the Enter key to step through the rotamers."
print "Type any character then Enter to terminate the script.\n"
print selR.type, "residue " + resStr + " selected."
print "Rotamer  Rotamer "
print "index:   probability:"

try:
    rot_L = getRotamers(selR)[1]
    numRots = len(rot_L)
    nullChar = ""
    rotIx = 0
    while nullChar == "":
        useRotamer(selR, [rot_L[rotIx]])
        printLine = "%2d       %7.5f" % (rotIx, rot_L[rotIx].rotamerProb)
        nullChar = raw_input(printLine)
        rotIx += 1
        rotIx = rotIx%numRots
        if rotIx == 0: print ""
    
except NoResidueRotamersError:
    print selR.id.position, selR.type, "No rotamers"
    


        
